<div id="data_{unique}">
    <?= get_instance()->session->flashdata('session_crud_message') ?: '' ?>
    {form_open}
    <input type="hidden" name="unique" value="{unique}"/>
    <input type="hidden" name="page" value="0"/>
    <input type="hidden" name="order" value=""/>
    <input type="hidden" name="ordertype" value="0"/>
    <input type="hidden" name="action" value=""/>
    <div class="topAction">
        {top_action}
    </div>
    <table class="table table-bordered table_over main_table table-hover">
        <thead>
            <tr>
                {column}
                <th {style}>{tooltip}{value}</th>
                {/column}
            </tr>
            <tr class="filter_head">
                <?php foreach ($column as $item) : ?>
                    <th>
                        <?= isset($item['filter']) ? $item['filter'] : '' ?>
                    </th>
                <?php endforeach; ?>
            </tr>
        </thead>
        <tbody>
            {rows}
        </tbody>
    </table>
    <div class="perpage">
        <div class="input-append">
            <select name="perpage" class="span1">
                {per_page}
                <option value="{value}" {selected}>{value}</option>
                {/per_page}
            </select>
            <span class="add-on"> / <span id="record_count">{record_count}</span></span>
        </div>
    </div>
    <div class="pagination right_pagin">
        <ul>
            {pagination}
        </ul>
    </div>
    {form_close}
</div>
