<?php

interface Rtgc_callback
{

    /**
     * @param string $value
     * @return string
     */
    public function column($value = '');

    /**
     * @param string $name
     * @param string|NULL $value
     * @return string
     */
    public function field($name = '', $value = NULL);
}
