<input type="hidden" class="multifield" name="{alias}" value="{value}" />
{field}
<div class="control-group">
    {value}
    <button data-name="{alias}" class="multifield_{class}"><i class="{btn}"></i></button>
</div>
{/field}

